@@ -38,16 +38,6 @@ EVENT_FILTER        = None
 UNIQUE_DIALOGS      = {}
 
 
-Gtk.rc_parse_string("""
-    style "hig" {
-        GtkDialog::content-area-border  = 0
-        GtkDialog::action-area-border   = 0
-    }
-
-    class "GtkDialog" style "hig"
-""")
-
-
 # EXCEPTIONS #
 
 class CancelError(Exception):
@@ -63,8 +53,9 @@ class Dialog(Gtk.Dialog):
     def __init__(self, parent, title):
         Gtk.Dialog.__init__(self, title=title)
 
-        self.set_border_width(12)
-        self.vbox.set_spacing(12)
+        content_area = self.get_content_area()
+        ui.apply_css_padding(content_area, 12)
+        content_area.set_spacing(12)
         self.set_resizable(False)
         self.set_modal(True)
         self.set_transient_for(parent)
@@ -79,73 +70,61 @@ class Dialog(Gtk.Dialog):
             self.response(Gtk.ResponseType.CLOSE)
             return True
 
+    def load_ui_section(self, resource_path, object_name, pack=True):
+        "Load a UI section from a resource file and optionally pack it into content area"
+        builder = Gtk.Builder()
+        builder.add_from_resource(resource_path)
+        section = builder.get_object(object_name)
+
+        if pack:
+            content_area = self.get_content_area()
+            content_area.pack_start(section, True, True, 0)
+
+        return builder, section
+
     def run(self):
         "Runs the dialog"
 
         self.show_all()
+        response = Gtk.Dialog.run(self)
 
-        while True:
+        # Handle edge case where ResponseType.NONE might be returned
+        # (e.g., on Wayland or in certain GTK3 scenarios)
+        # Retry once, but avoid infinite loop
+        if response == Gtk.ResponseType.NONE:
             response = Gtk.Dialog.run(self)
 
-            if response == Gtk.ResponseType.NONE:
-                continue
-
-            return response
+        return response
 
 
-class Popup(Gtk.Window):
-    "Base class for popup (frameless) dialogs"
-
-    def __init__(self, widget = None):
-        Gtk.Window.__init__(self)
-        self.set_decorated(False)
-
-        self.border = Gtk.Frame()
-        self.border.set_shadow_type(Gtk.ShadowType.OUT)
-        Gtk.Window.add(self, self.border)
-
-        if widget != None:
-            self.add(widget)
-
-        self.connect("key-press-event", self.__cb_keypress)
-
-    def __cb_keypress(self, widget, data):
-        "Callback for key presses"
-
-        if data.keyval == Gdk.KEY_Escape:
-            self.close()
-
-    def add(self, widget):
-        "Adds a widget to the window"
-
-        self.border.add(widget)
-
-    def close(self):
-        "Closes the dialog"
-
-        self.hide()
-        self.emit("closed")
-        self.destroy()
-
-    def realize(self):
-        "Realizes the popup and displays children"
-
-        Gtk.Window.realize(self)
-
-        for child in self.get_children():
-            child.show_all()
-
-    def show(self, x = None, y = None):
-        "Show the dialog"
-
-        if x != None and y != None:
-            self.move(x, y)
-
-        self.show_all()
+def load_ui_builder(resource_path):
+    "Helper function to load a UI builder from a resource file (for non-Dialog classes)"
+    builder = Gtk.Builder()
+    builder.add_from_resource(resource_path)
+    return builder
 
 
-GObject.signal_new("closed", Popup, GObject.SignalFlags.ACTION,
-                   GObject.TYPE_BOOLEAN, ())
+def replace_widget(builder, object_id, new_widget):
+    "Replace a widget from UI file with a custom widget"
+    ui_widget = builder.get_object(object_id)
+    widget_parent = ui_widget.get_parent()
+    widget_parent.remove(ui_widget)
+    widget_parent.pack_start(new_widget, True, True, 0)
+    widget_parent.show_all()
+    return new_widget
+
+
+def set_section_title(builder, object_id, text):
+    "Set a section title with bold markup"
+    title = builder.get_object(object_id)
+    title.set_markup(f"<span weight='bold'>{util.escape_markup(text)}</span>")
+
+
+def get_entry(builder, object_id):
+    "Get an entry widget from builder and set activates_default"
+    entry = builder.get_object(object_id)
+    entry.set_activates_default(True)
+    return entry
 
 
 class Utility(Dialog):
@@ -154,8 +133,7 @@ class Utility(Dialog):
     def __init__(self, parent, title):
         Dialog.__init__(self, parent, title)
 
-        self.set_border_width(12)
-        self.vbox.set_spacing(18)
+        self.get_content_area().set_spacing(18)
 
         self.sizegroup = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
 
@@ -163,7 +141,7 @@ class Utility(Dialog):
         "Adds an input section to the dialog"
 
         section = ui.InputSection(title, description, self.sizegroup)
-        self.vbox.pack_start(section, True, True, 0)
+        self.get_content_area().pack_start(section, True, True, 0)
 
         return section
 
@@ -174,28 +152,25 @@ class Message(Dialog):
     def __init__(self, parent, title, text, stockimage):
         Dialog.__init__(self, parent, "")
 
-        # hbox with image and contents
-        hbox = ui.HBox()
-        hbox.set_spacing(12)
-        self.vbox.pack_start(hbox, True, True, 0)
-        self.vbox.set_spacing(24)
+        # Load UI from file
+        builder, message_hbox = self.load_ui_section('/info/olasagasti/revelation/ui/message.ui', 'message_hbox')
+        content_area = self.get_content_area()
+        content_area.set_spacing(24)
 
-        # set up image
-        if stockimage != None:
-            image = ui.Image(stockimage, Gtk.IconSize.DIALOG)
-            image.set_valign(Gtk.Align.START)
-            hbox.pack_start(image, False, False, 0)
+        # Set up image (optional) - image is defined in XML
+        self.message_image = builder.get_object('message_image')
+        if stockimage is not None:
+            self.message_image.set_from_icon_name(stockimage, Gtk.IconSize.DIALOG)
+        else:
+            # Hide the image if no icon provided
+            self.message_image.set_visible(False)
 
-        # set up message
-        self.contents = ui.VBox()
-        self.contents.set_spacing(10)
-        hbox.pack_start(self.contents, True, True, 0)
+        # Get contents VBox from UI file
+        self.contents = builder.get_object('contents')
 
-        label = ui.Label("<span size=\"larger\" weight=\"bold\">%s</span>\n\n%s" % (util.escape_markup(title), text))
-        label.set_justify(Gtk.Justification.FILL)
-        label.set_selectable(True)
-        label.set_max_width_chars(45)
-        self.contents.pack_start(label, True, True, 0)
+        # Get message label and set markup
+        label = builder.get_object('message_label')
+        label.set_markup("<span size=\"larger\" weight=\"bold\">%s</span>\n\n%s" % (util.escape_markup(title), text))
 
     def run(self):
         "Displays the dialog"
@@ -212,7 +187,7 @@ class Error(Message):
 
     def __init__(self, parent, title, text):
         Message.__init__(self, parent, title, text, "dialog-error")
-        self.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+        self.add_button(_("_OK"), Gtk.ResponseType.OK)
 
 
 class Info(Message):
@@ -220,7 +195,7 @@ class Info(Message):
 
     def __init__(self, parent, title, text):
         Message.__init__(self, parent, title, text, "dialog-information")
-        self.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+        self.add_button(_("_OK"), Gtk.ResponseType.OK)
 
 
 class Question(Message):
@@ -228,7 +203,7 @@ class Question(Message):
 
     def __init__(self, parent, title, text):
         Message.__init__(self, parent, title, text, "dialog-question")
-        self.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+        self.add_button(_("_OK"), Gtk.ResponseType.OK)
 
 
 class Warning(Message):
@@ -248,7 +223,7 @@ class FileChanged(Warning):
             self, parent, _('File has changed'), _('The current file \'%s\' has changed. Do you want to reload it?') % filename
         )
 
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
         self.add_button(ui.STOCK_RELOAD, Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.OK)
 
@@ -268,9 +243,9 @@ class FileChanges(Warning):
     def __init__(self, parent, title, text):
         Warning.__init__(self, parent, title, text)
 
-        self.add_button(Gtk.STOCK_DISCARD, Gtk.ResponseType.ACCEPT)
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-        self.add_button(Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
+        self.add_button(_("_Discard"), Gtk.ResponseType.ACCEPT)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Save"), Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.OK)
 
     def run(self):
@@ -337,7 +312,7 @@ class FileReplace(Warning):
             _('The file \'%s\' already exists - do you wish to replace this file?') % file
         )
 
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
         self.add_button(ui.STOCK_REPLACE, Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.CANCEL)
 
@@ -360,8 +335,8 @@ class FileSaveInsecure(Warning):
             _('You have chosen to save your passwords to an insecure (unencrypted) file format - if anyone has access to this file, they will be able to see your passwords.'),
         )
 
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-        self.add_button(Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Save"), Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.CANCEL)
 
     def run(self):
@@ -550,10 +525,10 @@ class SaveFileSelector(FileSelector):
 class Password(Message):
     "A base dialog for asking for passwords"
 
-    def __init__(self, parent, title, text, stock = Gtk.STOCK_OK):
+    def __init__(self, parent, title, text, stock = _("_OK")):
         Message.__init__(self, parent, title, text, "dialog-password")
 
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
         self.add_button(stock, Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.OK)
 
@@ -597,13 +572,37 @@ class PasswordChange(Password):
 
         self.password = password
 
-        if password is not None:
-            self.entry_current = self.add_entry(_('Current password'))
+        # Load password section from UI file
+        builder, password_section = self.load_ui_section('/info/olasagasti/revelation/ui/password-change.ui', 'password_section', pack=False)
 
-        self.entry_new      = self.add_entry(_('New password'), ui.PasswordEntry())
-        self.entry_confirm  = self.add_entry(_('Confirm password'))
+        # Replace the InputSection with UI file content
+        # Remove the old InputSection
+        self.contents.remove(self.sect_passwords)
+        # Add the UI file section
+        self.contents.pack_start(password_section, True, True, 0)
+
+        # Get the current password entry from UI file (optional)
+        current_entry_row = builder.get_object('current_password_entry').get_parent()
+        if password is not None:
+            self.entry_current = get_entry(builder, 'current_password_entry')
+        else:
+            # Hide the current password row if password is None
+            current_entry_row.set_visible(False)
+            self.entry_current = None
+
+        # Get the new password entry from UI file and replace with PasswordEntry
+        self.entry_new = replace_widget(builder, 'new_password_entry', ui.PasswordEntry())
+
+        # Get the confirm password entry from UI file
+        self.entry_confirm = get_entry(builder, 'confirm_password_entry')
         self.entry_confirm.autocheck = False
 
+        # Build entries list
+        self.entries = []
+        if self.entry_current is not None:
+            self.entries.append(self.entry_current)
+        self.entries.extend([self.entry_new, self.entry_confirm])
+
     def run(self):
         "Displays the dialog"
 
@@ -630,8 +629,8 @@ class PasswordChange(Password):
                         _('The password you entered is not secure; %s. Are you sure you want to use it?') % str(res).lower()
                     )
 
-                    WarnInsecure.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-                    WarnInsecure.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+                    WarnInsecure.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
+                    WarnInsecure.add_button(_("_OK"), Gtk.ResponseType.OK)
                     WarnInsecure.set_default_response(Gtk.ResponseType.CANCEL)
 
                     response = WarnInsecure.run()
@@ -652,11 +651,23 @@ class PasswordLock(Password):
             ui.STOCK_UNLOCK
         )
 
-        self.get_widget_for_response(Gtk.ResponseType.CANCEL).set_label(Gtk.STOCK_QUIT)
+        self.get_widget_for_response(Gtk.ResponseType.CANCEL).set_label(_("_Quit"))
         self.set_default_response(Gtk.ResponseType.OK)
 
         self.password = password
-        self.entry_password = self.add_entry(_('Password'))
+
+        # Load password section from UI file
+        builder, password_section = self.load_ui_section('/info/olasagasti/revelation/ui/password-lock.ui', 'password_section', pack=False)
+
+        # Replace the InputSection with UI file content
+        # Remove the old InputSection
+        self.contents.remove(self.sect_passwords)
+        # Add the UI file section
+        self.contents.pack_start(password_section, True, True, 0)
+
+        # Get the password entry from UI file
+        self.entry_password = get_entry(builder, 'password_entry')
+        self.entries = [self.entry_password]
 
     def run(self):
         "Displays the dialog"
@@ -678,7 +689,7 @@ class PasswordLock(Password):
                     Error(self, _('Incorrect password'), _('The password you entered was not correct, please try again.')).run()
 
             except CancelError:
-                if self.get_widget_for_response(Gtk.ResponseType.CANCEL).get_property("sensitive") == True:
+                if self.get_widget_for_response(Gtk.ResponseType.CANCEL).get_property("sensitive"):
                     self.destroy()
                     raise
 
@@ -695,11 +706,23 @@ class PasswordOpen(Password):
         Password.__init__(
             self, parent, _('Enter file password'),
             _('The file “%s” is encrypted. Please enter the file password to open it.') % filename,
-            Gtk.STOCK_OPEN
+            _("_Open")
         )
 
         self.set_default_response(Gtk.ResponseType.OK)
-        self.entry_password = self.add_entry(_('Password'))
+
+        # Load password section from UI file
+        builder, password_section = self.load_ui_section('/info/olasagasti/revelation/ui/password-open.ui', 'password_section', pack=False)
+
+        # Replace the InputSection with UI file content
+        # Remove the old InputSection
+        self.contents.remove(self.sect_passwords)
+        # Add the UI file section
+        self.contents.pack_start(password_section, True, True, 0)
+
+        # Get the password entry from UI file
+        self.entry_password = get_entry(builder, 'password_entry')
+        self.entries = [self.entry_password]
 
     def run(self):
         "Displays the dialog"
@@ -722,13 +745,27 @@ class PasswordSave(Password):
         Password.__init__(
             self, parent, _('Enter password for file'),
             _('Please enter a password for the file \'%s\'. You will need this password to open the file at a later time.') % filename,
-            Gtk.STOCK_SAVE
+            _("_Save")
         )
 
-        self.entry_new      = self.add_entry(_('New password'), ui.PasswordEntry())
-        self.entry_confirm  = self.add_entry(_('Confirm password'))
+        # Load password section from UI file
+        builder, password_section = self.load_ui_section('/info/olasagasti/revelation/ui/password-save.ui', 'password_section', pack=False)
+
+        # Replace the InputSection with UI file content
+        # Remove the old InputSection
+        self.contents.remove(self.sect_passwords)
+        # Add the UI file section
+        self.contents.pack_start(password_section, True, True, 0)
+
+        # Get the new password entry from UI file and replace with PasswordEntry
+        self.entry_new = replace_widget(builder, 'new_password_entry', ui.PasswordEntry())
+
+        # Get the confirm password entry from UI file
+        self.entry_confirm = get_entry(builder, 'confirm_password_entry')
         self.entry_confirm.autocheck = False
 
+        self.entries = [self.entry_new, self.entry_confirm]
+
     def run(self):
         "Displays the dialog"
 
@@ -757,8 +794,8 @@ class PasswordSave(Password):
                         _('The password you entered is not secure; %s. Are you sure you want to use it?') % res
                     )
 
-                    WarnInsecure.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-                    WarnInsecure.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+                    WarnInsecure.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
+                    WarnInsecure.add_button(_("_OK"), Gtk.ResponseType.OK)
                     WarnInsecure.set_default_response(Gtk.ResponseType.CANCEL)
 
                     response = WarnInsecure.run()
@@ -777,7 +814,7 @@ class EntryEdit(Utility):
     def __init__(self, parent, title, e = None, cfg = None, clipboard = None):
         Utility.__init__(self, parent, title)
 
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
         if not e:
             self.add_button(ui.STOCK_NEW_ENTRY, Gtk.ResponseType.OK)
         else:
@@ -790,29 +827,50 @@ class EntryEdit(Utility):
         self.fielddata   = {}
         self.widgetdata  = {}
 
-        # set up the ui
-        self.sect_meta      = self.add_section(title)
-        self.sect_fields    = self.add_section(_('Account Data'))
-        self.sect_notes     = self.add_section(_('Notes'))
+        # Load UI from file
+        builder, unused_section = self.load_ui_section('/info/olasagasti/revelation/ui/entry-edit.ui', 'meta_section', pack=False)
 
-        self.entry_name = ui.Entry()
-        self.entry_name.set_width_chars(50)
-        self.entry_name.set_tooltip_text(_('The name of the entry'))
-        self.sect_meta.append_widget(_('Name'), self.entry_name)
+        # Get sections from UI file
+        meta_section = builder.get_object('meta_section')
+        notes_section = builder.get_object('notes_section')
 
-        self.entry_desc = ui.Entry()
-        self.entry_desc.set_tooltip_text(_('A description of the entry'))
-        self.sect_meta.append_widget(_('Description'), self.entry_desc)
+        # Set section titles with markup
+        set_section_title(builder, 'meta_title', title)
+        set_section_title(builder, 'notes_title', _('Notes'))
 
+        # Add sections to dialog
+        content_area = self.get_content_area()
+        content_area.pack_start(meta_section, True, True, 0)
+        self.sect_fields = self.add_section(_('Account Data'))
+        content_area.pack_start(notes_section, True, True, 0)
+
+        # Get entry widgets from UI file
+        self.entry_name = get_entry(builder, 'name_entry')
+        self.entry_desc = get_entry(builder, 'description_entry')
+
+        # Add EntryDropDown to EventBox container (defined in XML)
+        dropdown_container = builder.get_object('type_dropdown_container')
         self.dropdown = ui.EntryDropDown()
         self.dropdown.connect("changed", lambda w: self.__setup_fieldsect(self.dropdown.get_active_type()().fields))
-        eventbox = ui.EventBox(self.dropdown)
-        eventbox.set_tooltip_text(_('The type of entry'))
-        self.sect_meta.append_widget(_('Type'), eventbox)
+        dropdown_container.add(self.dropdown)
+        dropdown_container.show_all()
 
+        # Replace notes placeholder with EditableTextView
+        notes_placeholder = builder.get_object('notes_placeholder')
+        notes_placeholder_parent = notes_placeholder.get_parent()
+        notes_placeholder_parent.remove(notes_placeholder)
         self.entry_notes = ui.EditableTextView()
         self.entry_notes.set_tooltip_text(_('Notes for the entry'))
-        self.sect_notes.append_widget(None, self.entry_notes)
+        notes_placeholder_parent.pack_start(self.entry_notes, True, True, 0)
+        notes_placeholder_parent.show_all()
+
+        # Add labels to sizegroup for alignment
+        name_label = builder.get_object('name_label')
+        description_label = builder.get_object('description_label')
+        type_label = builder.get_object('type_label')
+        self.sizegroup.add_widget(name_label)
+        self.sizegroup.add_widget(description_label)
+        self.sizegroup.add_widget(type_label)
 
         # populate the dialog with data
         self.set_entry(e)
@@ -848,7 +906,7 @@ class EntryEdit(Utility):
             if hasattr(fieldentry, "set_tooltip_text"):
                 fieldentry.set_tooltip_text(field.description)
 
-            elif hasattr(fieldentry, "entry") == True:
+            elif hasattr(fieldentry, "entry"):
                 fieldentry.entry.set_tooltip_text(field.description)
 
             self.sect_fields.append_widget(field.name, fieldentry)
@@ -931,8 +989,8 @@ class EntryRemove(Warning):
 
         Warning.__init__(self, parent, title, text)
 
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-        self.add_button(Gtk.STOCK_REMOVE, Gtk.ResponseType.OK)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Remove"), Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.CANCEL)
 
     def run(self):
@@ -951,24 +1009,28 @@ class FolderEdit(Utility):
     def __init__(self, parent, title, e = None):
         Utility.__init__(self, parent, title)
 
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
         if not e:
             self.add_button(ui.STOCK_NEW_FOLDER, Gtk.ResponseType.OK)
         else:
             self.add_button(ui.STOCK_UPDATE, Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.OK)
 
-        # set up the ui
-        self.sect_folder    = self.add_section(title)
+        # Load UI from file
+        builder, section = self.load_ui_section('/info/olasagasti/revelation/ui/folder-edit.ui', 'folder_section')
 
-        self.entry_name = ui.Entry()
-        self.entry_name.set_width_chars(25)
-        self.entry_name.set_tooltip_text(_('The name of the folder'))
-        self.sect_folder.append_widget(_('Name'), self.entry_name)
+        # Set section title with markup
+        set_section_title(builder, 'section_title', title)
 
-        self.entry_desc = ui.Entry()
-        self.entry_desc.set_tooltip_text(_('A description of the folder'))
-        self.sect_folder.append_widget(_('Description'), self.entry_desc)
+        # Get entry widgets from UI file
+        self.entry_name = get_entry(builder, 'name_entry')
+        self.entry_desc = get_entry(builder, 'description_entry')
+
+        # Add labels to sizegroup for alignment
+        name_label = builder.get_object('name_label')
+        description_label = builder.get_object('description_label')
+        self.sizegroup.add_widget(name_label)
+        self.sizegroup.add_widget(description_label)
 
         # populate the dialog with data
         self.set_entry(e)
@@ -1023,6 +1085,16 @@ class About(Gtk.AboutDialog):
         if isinstance(parent, Gtk.Window):
             self.set_transient_for(parent)
 
+        # Load static properties from UI file
+        builder = load_ui_builder('/info/olasagasti/revelation/ui/about.ui')
+        ui_dialog = builder.get_object('about_dialog')
+
+        # Copy static properties from UI file
+        self.set_property("program-name", ui_dialog.get_property("program-name"))
+        self.set_property("website-label", ui_dialog.get_property("website-label"))
+        self.set_property("license-type", ui_dialog.get_property("license-type"))
+
+        # Set properties from config (source of truth)
         self.set_name(config.APPNAME)
         self.set_version(config.VERSION)
         self.set_copyright(config.COPYRIGHT)
@@ -1047,17 +1119,25 @@ class Exception(Error):
     def __init__(self, parent, traceback):
         Error.__init__(
             self, parent, _('Unknown error'),
-            _('An unknown error occured. Please report the text below to the Revelation developers, along with what you were doing that may have caused the error. You may attempt to continue running Revelation, but it may behave unexpectedly.')
+            _('An unknown error occurred. Please report the text below to the Revelation developers, along with what you were doing that may have caused the error. You may attempt to continue running Revelation, but it may behave unexpectedly.')
         )
 
-        self.add_button(Gtk.STOCK_QUIT, Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Quit"), Gtk.ResponseType.CANCEL)
         self.add_button(ui.STOCK_CONTINUE, Gtk.ResponseType.OK)
 
-        textview = ui.TextView(None, traceback)
-        scrolledwindow = ui.ScrolledWindow(textview)
-        scrolledwindow.set_size_request(-1, 120)
+        # Load traceback section from UI file
+        builder, unused_section = self.load_ui_section('/info/olasagasti/revelation/ui/exception.ui', 'exception_section', pack=False)
 
-        self.contents.pack_start(scrolledwindow, True, True, 0)
+        # Get the scrolled window from UI file
+        ui_scrolled = builder.get_object('traceback_scrolled')
+        # Replace the textview with custom ui.TextView
+        ui_textview = builder.get_object('traceback_textview')
+        textview = ui.TextView(None, traceback)
+        # Replace the textview in the scrolled window
+        ui_scrolled.remove(ui_textview)
+        ui_scrolled.add(textview)
+
+        self.contents.pack_start(ui_scrolled, True, True, 0)
 
     def run(self):
         "Runs the dialog"
@@ -1071,25 +1151,36 @@ class PasswordChecker(Utility):
     def __init__(self, parent, cfg = None, clipboard = None):
         Utility.__init__(self, parent, _('Password Checker'))
 
-        self.add_button(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
+        self.add_button(_("_Close"), Gtk.ResponseType.CLOSE)
         self.set_default_response(Gtk.ResponseType.CLOSE)
 
         self.cfg = cfg
         self.set_modal(False)
         self.set_size_request(300, -1)
 
-        self.section = self.add_section(_('Password Checker'))
+        # Load UI from file
+        builder, section = self.load_ui_section('/info/olasagasti/revelation/ui/password-checker.ui', 'password_checker_section')
 
-        self.entry = ui.PasswordEntry(None, cfg, clipboard)
+        # Set section title with markup
+        set_section_title(builder, 'section_title', _('Password Checker'))
+
+        # Get password entry from UI file and replace with PasswordEntry
+        self.entry = replace_widget(builder, 'password_entry', ui.PasswordEntry(None, cfg, clipboard))
         self.entry.autocheck = False
         self.entry.set_width_chars(40)
         self.entry.connect("changed", self.__cb_changed)
         self.entry.set_tooltip_text(_('Enter a password to check'))
-        self.section.append_widget(_('Password'), self.entry)
 
-        self.result = ui.ImageLabel(_('Enter a password to check'), ui.STOCK_UNKNOWN, ui.ICON_SIZE_HEADLINE)
-        self.result.set_tooltip_text(_('The result of the check'))
-        self.section.append_widget(None, self.result)
+        # Get result display widgets from UI file (Box with Image and Label)
+        self.result_container = builder.get_object('result_container')
+        self.result_image = builder.get_object('result_image')
+        self.result_label = builder.get_object('result_label')
+        # Set initial icon
+        self.result_image.set_from_icon_name(ui.STOCK_UNKNOWN, ui.ICON_SIZE_HEADLINE)
+
+        # Add label to sizegroup for alignment
+        password_label = builder.get_object('password_label')
+        self.sizegroup.add_widget(password_label)
 
         self.connect("response", self.__cb_response)
 
@@ -1112,8 +1203,8 @@ class PasswordChecker(Utility):
             icon    = ui.STOCK_PASSWORD_WEAK
             result = _('The password %s') % str(reason)
 
-        self.result.set_text(result)
-        self.result.set_stock(icon, ui.ICON_SIZE_HEADLINE)
+        self.result_label.set_markup(util.escape_markup(result))
+        self.result_image.set_from_icon_name(icon, ui.ICON_SIZE_HEADLINE)
 
     def __cb_response(self, widget, response):
         "Callback for response"
@@ -1137,32 +1228,33 @@ class PasswordGenerator(Utility):
     def __init__(self, parent, cfg, clipboard = None):
         Utility.__init__(self, parent, _('Password Generator'))
 
-        self.add_button(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
+        self.add_button(_("_Close"), Gtk.ResponseType.CLOSE)
         self.add_button(ui.STOCK_GENERATE, Gtk.ResponseType.OK)
 
         self.config = cfg
         self.set_modal(False)
 
-        self.section = self.add_section(_('Password Generator'))
+        # Load UI from file
+        builder, section = self.load_ui_section('/info/olasagasti/revelation/ui/password-generator.ui', 'password_generator_section')
 
-        self.entry = ui.PasswordEntry(None, cfg, clipboard)
+        # Set section title with markup
+        set_section_title(builder, 'section_title', _('Password Generator'))
+
+        # Get widgets from UI file
+        self.entry = replace_widget(builder, 'password_entry', ui.PasswordEntry(None, cfg, clipboard))
         self.entry.autocheck = False
         self.entry.set_editable(False)
         self.entry.set_tooltip_text(_('The generated password'))
-        self.section.append_widget(_('Password'), self.entry)
 
-        self.spin_pwlen = ui.SpinEntry()
-        self.spin_pwlen.set_range(4, 256)
+        # Get spin button from UI file (range and adjustment already set in XML)
+        self.spin_pwlen = builder.get_object('length_spin')
         self.config.bind("passwordgen-length", self.spin_pwlen, "value", Gio.SettingsBindFlags.DEFAULT)
-        self.spin_pwlen.set_tooltip_text(_('The number of characters in generated passwords - 8 or more are recommended'))
-        self.section.append_widget(_('Length'), self.spin_pwlen)
 
-        self.check_punctuation_chars = ui.CheckButton(_('Use punctuation characters for passwords'))
+        self.check_punctuation_chars = builder.get_object('punctuation_check')
         if self.config.get_int("passwordgen-length"):
             self.check_punctuation_chars.set_sensitive(True)
         self.config.bind("passwordgen-punctuation", self.check_punctuation_chars, "active", Gio.SettingsBindFlags.DEFAULT)
         self.check_punctuation_chars.set_tooltip_text(_('When passwords are generated, use punctuation characters like %, =, { or .'))
-        self.section.append_widget(None, self.check_punctuation_chars)
 
         self.connect("response", self.__cb_response)
 
@@ -1184,39 +1276,32 @@ class PasswordGenerator(Utility):
 
 # FUNCTIONS #
 
-def create_unique(dialog, *args):
-    "Creates a unique dialog"
+def create_unique_dialog(dialog, *args):
+    "Creates a unique dialog or returns existing one"
 
-    if present_unique(dialog) == True:
+    if unique_exists(dialog):
         return get_unique(dialog)
 
-    else:
-        UNIQUE_DIALOGS[dialog] = dialog(*args)
-        UNIQUE_DIALOGS[dialog].connect("destroy", lambda w: remove_unique(dialog))
-
-        return UNIQUE_DIALOGS[dialog]
+    UNIQUE_DIALOGS[dialog] = dialog(*args)
+    UNIQUE_DIALOGS[dialog].connect("destroy", lambda w: remove_unique(dialog))
+    return UNIQUE_DIALOGS[dialog]
 
 
 def get_unique(dialog):
-    "Returns a unique dialog"
+    "Returns a unique dialog if it exists, None otherwise"
 
-    if unique_exists(dialog) == True:
+    if unique_exists(dialog):
         return UNIQUE_DIALOGS[dialog]
-
-    else:
-        return None
+    return None
 
 
 def present_unique(dialog):
-    "Presents a unique dialog, if it exists"
+    "Presents a unique dialog if it exists, returns True if presented"
 
-    if unique_exists(dialog) == True:
+    if unique_exists(dialog):
         get_unique(dialog).present()
-
         return True
-
-    else:
-        return False
+    return False
 
 
 def remove_unique(dialog):
@@ -1226,19 +1311,17 @@ def remove_unique(dialog):
         UNIQUE_DIALOGS[dialog] = None
 
 
-def run_unique(dialog, *args):
-    "Runs a unique dialog"
+def run_unique_dialog(dialog, *args):
+    "Runs a unique dialog, returns None if already presented"
 
-    if present_unique(dialog) == True:
+    if present_unique(dialog):
         return None
 
-    else:
-        d = create_unique(dialog, *args)
-
-        return d.run()
+    d = create_unique_dialog(dialog, *args)
+    return d.run()
 
 
 def unique_exists(dialog):
     "Checks if a unique dialog exists"
 
-    return dialog in UNIQUE_DIALOGS and UNIQUE_DIALOGS[dialog] != None
+    return dialog in UNIQUE_DIALOGS and UNIQUE_DIALOGS[dialog] is not None
