@@ -61,9 +61,9 @@ STOCK_UPDATE            = _("_Update")                 # "revelation-update"
 
 STOCK_ENTRY_FOLDER      = "folder"              # "revelation-account-folder"
 STOCK_ENTRY_FOLDER_OPEN = "folder-open"         # "revelation-account-folder-open"
-STOCK_ENTRY_CREDITCARD  = "x-office-contact"    # "revelation-account-creditcard"
+STOCK_ENTRY_CREDITCARD  = "application-x-executable"  # "revelation-account-creditcard"
 STOCK_ENTRY_CRYPTOKEY   = "dialog-password"     # "revelation-account-cryptokey"
-STOCK_ENTRY_DATABASE    = "server-database"     # "revelation-account-database"
+STOCK_ENTRY_DATABASE    = "drive-harddisk"      # "revelation-account-database"
 STOCK_ENTRY_DOOR        = "changes-allow"       # "revelation-account-door"
 STOCK_ENTRY_EMAIL       = "emblem-mail"         # "revelation-account-email"
 STOCK_ENTRY_FTP         = "system-file-manager"  # "revelation-account-ftp"
@@ -84,48 +84,6 @@ ICON_SIZE_LABEL         = Gtk.IconSize.MENU
 ICON_SIZE_LOGO          = Gtk.IconSize.DND
 ICON_SIZE_TREEVIEW      = Gtk.IconSize.MENU
 
-STOCK_ICONS = (
-    (STOCK_ENTRY_CREDITCARD,   "contact-new",          (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_CRYPTOKEY,    "dialog-password",      (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_DATABASE,     "package_system",       (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_DOOR,         "changes-allow",        (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_EMAIL,        "emblem-mail",          (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_FTP,          "system-file-manager",  (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_GENERIC,      "document-new",         (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_PHONE,        "phone",                (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_SHELL,        "utilities-terminal",   (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_REMOTEDESKTOP, "preferences-desktop-remote-desktop", (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_WEBSITE,      "web-browser",          (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_FOLDER,       "folder",               (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-    (STOCK_ENTRY_FOLDER_OPEN,  "folder-open",          (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
-)
-
-STOCK_ITEMS = (
-    (STOCK_CONTINUE,       _('_Continue'),     "stock_test-mode"),
-    (STOCK_DISCARD,        _('_Discard'),      Gtk.STOCK_DELETE),
-    (STOCK_EDIT,           _('_Edit'),         Gtk.STOCK_EDIT),
-    (STOCK_EXPORT,         _('_Export'),       Gtk.STOCK_EXECUTE),
-    (STOCK_FOLDER,         '',                 "stock_folder"),
-    (STOCK_GENERATE,       _('_Generate'),     Gtk.STOCK_EXECUTE),
-    (STOCK_GOTO,           _('_Go to'),        Gtk.STOCK_JUMP_TO),
-    (STOCK_IMPORT,         _('_Import'),       Gtk.STOCK_CONVERT),
-    (STOCK_LOCK,           _('_Lock'),         "stock_lock"),
-    (STOCK_NEW_ENTRY,      _('_Add Entry'),    Gtk.STOCK_ADD),
-    (STOCK_NEW_FOLDER,     _('_Add Folder'),   "stock_folder"),
-    (STOCK_NEXT,           _('Next'),          Gtk.STOCK_GO_DOWN),
-    (STOCK_PASSWORD_CHANGE, _('_Change'),       "stock_lock-ok"),
-    (STOCK_PASSWORD_CHECK, _('_Check'),        "stock_lock-ok"),
-    (STOCK_PASSWORD_STRONG, '',                 "stock_lock-ok"),
-    (STOCK_PASSWORD_WEAK,  '',                 "stock_lock-broken"),
-    (STOCK_PREVIOUS,       _('Previous'),      Gtk.STOCK_GO_UP),
-    (STOCK_RELOAD,         _('_Reload'),       Gtk.STOCK_REFRESH),
-    (STOCK_REMOVE,         _('Re_move'),       Gtk.STOCK_DELETE),
-    (STOCK_REPLACE,        _('_Replace'),      Gtk.STOCK_SAVE_AS),
-    (STOCK_UNKNOWN,        _('Unknown'),       "dialog-question"),
-    (STOCK_UNLOCK,         _('_Unlock'),       "stock_lock-open"),
-    (STOCK_UPDATE,         _('_Update'),       "stock_edit"),
-)
-
 
 # EXCEPTIONS #
 
@@ -136,6 +94,20 @@ class DataError(Exception):
 
 # FUNCTIONS #
 
+def apply_css_padding(widget, padding):
+    "Apply CSS padding to a widget (replaces set_border_width)"
+    # Add CSS class with padding value to avoid conflicts between different padding values
+    css_class = f"revelation-padding-{padding}"
+    style_context = widget.get_style_context()
+    style_context.add_class(css_class)
+
+    # Create CSS provider with the class selector
+    css_provider = Gtk.CssProvider()
+    css = f".{css_class} {{ padding: {padding}px; }}"
+    css_provider.load_from_data(css.encode())
+    style_context.add_provider(css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
+
+
 def generate_field_display_widget(field, cfg = None, userdata = None):
     "Generates a widget for displaying a field value"
 
@@ -212,119 +184,13 @@ def setup_comboboxentry(widget, userdata=None):
 
 # CONTAINERS #
 
-class HBox(Gtk.HBox):
-    "A horizontal container"
 
-    def __init__(self, *args):
-        Gtk.HBox.__init__(self)
-
-        self.set_spacing(6)
-        self.set_border_width(0)
-
-        for widget in args:
-            self.pack_start(widget, True, True, 0)
-
-
-class HButtonBox(Gtk.HButtonBox):
-    "A horizontal button box"
-
-    def __init__(self, *args):
-        Gtk.HButtonBox.__init__(self)
-
-        self.set_layout(Gtk.ButtonBoxStyle.SPREAD)
-        self.set_spacing(12)
-
-        for button in args:
-            self.pack_start(button, True, True, 0)
-
-
-class VBox(Gtk.VBox):
-    "A vertical container"
-
-    def __init__(self, *args):
-        Gtk.VBox.__init__(self)
-
-        self.set_spacing(6)
-        self.set_border_width(0)
-
-        for widget in args:
-            self.pack_start(widget, True, True, 0)
-
-
-class Notebook(Gtk.Notebook):
-    "A notebook (tabbed view)"
-
-    def __init__(self):
-        Gtk.Notebook.__init__(self)
-
-    def create_page(self, title):
-        "Creates a notebook page"
-
-        page = NotebookPage()
-        self.append_page(page, Label(title))
-
-        return page
-
-
-class NotebookPage(VBox):
-    "A notebook page"
-
-    def __init__(self):
-        VBox.__init__(self)
-
-        self.sizegroup = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
-        self.set_border_width(12)
-        self.set_spacing(18)
-
-    def add_section(self, title, description = None):
-        "Adds an input section to the notebook"
-
-        section = InputSection(title, description, self.sizegroup)
-        self.pack_start(section, False, False, 0)
-
-        return section
-
-
-class ScrolledWindow(Gtk.ScrolledWindow):
-    "A scrolled window for partially displaying a child widget"
-
-    def __init__(self, contents = None):
-        Gtk.ScrolledWindow.__init__(self)
-
-        self.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
-
-        if contents is not None:
-            self.add(contents)
-
-
-class Toolbar(Gtk.Toolbar):
-    "A Toolbar subclass"
-
-    def append_space(self):
-        "Appends a space to the toolbar"
-
-        space = Gtk.SeparatorToolItem()
-        space.set_draw(False)
-
-        self.insert(space, -1)
-
-    def append_widget(self, widget, tooltip = None):
-        "Appends a widget to the toolbar"
-
-        toolitem = Gtk.ToolItem()
-        toolitem.add(widget)
-
-        if tooltip != None:
-            toolitem.set_tooltip_text(tooltip)
-
-        self.insert(toolitem, -1)
-
-
-class InputSection(VBox):
+class InputSection(Gtk.Box):
     "A section of input fields"
 
     def __init__(self, title = None, description = None, sizegroup = None):
-        VBox.__init__(self)
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL)
+        self.set_spacing(6)
 
         self.title  = None
         self.desc   = None
@@ -344,11 +210,11 @@ class InputSection(VBox):
     def append_widget(self, title, widget, indent = True):
         "Adds a widget to the section"
 
-        row = HBox()
+        row = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
         row.set_spacing(12)
         self.pack_start(row, False, False, 0)
 
-        if self.title is not None and indent == True:
+        if self.title is not None and indent:
             row.pack_start(Label(""), False, False, 0)
 
         if title is not None:
@@ -368,48 +234,21 @@ class InputSection(VBox):
 
 # DISPLAY WIDGETS #
 
-class EventBox(Gtk.EventBox):
-    "A container which handles events for a widget (for tooltips etc)"
-
-    def __init__(self, widget = None):
-        Gtk.EventBox.__init__(self)
-
-        if widget is not None:
-            self.add(widget)
-
-
-class Image(Gtk.Image):
-    "A widget for displaying an image"
-
-    def __init__(self, stock = None, size = None):
-        Gtk.Image.__init__(self)
-
-        if stock is not None:
-            self.set_from_icon_name(stock, size)
-
-
-class ImageLabel(HBox):
+class ImageLabel(Gtk.Box):
     "A label with an image"
 
     def __init__(self, text = None, stock = None, size = ICON_SIZE_LABEL):
-        HBox.__init__(self)
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
+        self.set_spacing(6)
 
-        self.image = Image()
+        self.image = Gtk.Image()
         self.pack_start(self.image, False, True, 0)
 
         self.label = Label(text)
         self.pack_start(self.label, True, True, 0)
 
-        if text != None:
-            self.set_text(text)
-
-        if stock != None:
-            self.set_stock(stock, size)
-
-    def set_ellipsize(self, ellipsize):
-        "Sets label ellisization"
-
-        self.label.set_ellipsize(ellipsize)
+        if stock is not None:
+            self.image.set_from_icon_name(stock, size)
 
     def set_stock(self, stock, size):
         "Sets the image"
@@ -425,6 +264,13 @@ class ImageLabel(HBox):
 class Label(Gtk.Label):
     "A text label"
 
+    # Map justification to horizontal alignment
+    _JUSTIFY_TO_ALIGN = {
+        Gtk.Justification.LEFT: Gtk.Align.START,
+        Gtk.Justification.CENTER: Gtk.Align.CENTER,
+        Gtk.Justification.RIGHT: Gtk.Align.END,
+    }
+
     def __init__(self, text = None, justify = Gtk.Justification.LEFT):
         Gtk.Label.__init__(self)
 
@@ -434,30 +280,22 @@ class Label(Gtk.Label):
         self.set_line_wrap(True)
 
         self.set_valign(Gtk.Align.CENTER)
-        if justify == Gtk.Justification.LEFT:
-            self.set_halign(Gtk.Align.START)
-
-        elif justify == Gtk.Justification.CENTER:
-            self.set_halign(Gtk.Align.CENTER)
-
-        elif justify == Gtk.Justification.RIGHT:
-            self.set_halign(Gtk.Align.END)
+        self.set_halign(self._JUSTIFY_TO_ALIGN.get(justify, Gtk.Align.START))
 
     def set_text(self, text):
         "Sets the text of the label"
 
         if text is None:
             Gtk.Label.set_text(self, "")
-
         else:
             Gtk.Label.set_markup(self, text)
 
 
-class PasswordLabel(EventBox):
+class PasswordLabel(Gtk.EventBox):
     "A label for displaying passwords"
 
     def __init__(self, password = "", cfg = None, clipboard = None, justify = Gtk.Justification.LEFT):  # nosec
-        EventBox.__init__(self)
+        Gtk.EventBox.__init__(self)
 
         self.password   = util.unescape_markup(password)
         self.config = cfg
@@ -481,13 +319,13 @@ class PasswordLabel(EventBox):
     def __cb_button_press(self, widget, data = None):
         "Populates the popup menu"
 
-        if self.label.get_selectable() == True:
+        if self.label.get_selectable():
             return False
 
         elif data.button == 3:
             menu = Menu()
 
-            menuitem = ImageMenuItem(Gtk.STOCK_COPY, _('Copy password'))
+            menuitem = ImageMenuItem("edit-copy", _('Copy password'))
             menuitem.connect("activate", lambda w: self.clipboard.set([self.password], True))
             menu.append(menuitem)
 
@@ -504,7 +342,7 @@ class PasswordLabel(EventBox):
     def show_password(self, show = True):
         "Sets whether to display the password"
 
-        if show == True:
+        if show:
             self.label.set_text(util.escape_markup(self.password))
             self.label.set_selectable(True)
             self.drag_source_unset()
@@ -580,22 +418,16 @@ class Entry(Gtk.Entry):
         Gtk.Entry.__init__(self)
 
         self.set_activates_default(True)
-        self.set_text(text)
-
-    def set_text(self, text):
-        "Sets the entry contents"
-
-        if text is None:
-            text = ""
-
-        Gtk.Entry.set_text(self, text)
+        if text is not None:
+            Gtk.Entry.set_text(self, text)
 
 
-class FileEntry(HBox):
+class FileEntry(Gtk.Box):
     "A file entry"
 
     def __init__(self, title = None, file = None, type = Gtk.FileChooserAction.OPEN):
-        HBox.__init__(self)
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
+        self.set_spacing(6)
 
         self.title = title is not None and title or _('Select File')
         self.type = type
@@ -604,7 +436,8 @@ class FileEntry(HBox):
         self.entry.connect("changed", lambda w: self.emit("changed"))
         self.pack_start(self.entry, True, True, 0)
 
-        self.button = Button(_('Browse...'), self.__cb_filesel)
+        self.button = Gtk.Button(label=_('Browse...'))
+        self.button.connect("clicked", self.__cb_filesel)
         self.pack_start(self.button, False, False, 0)
 
         if file is not None:
@@ -614,13 +447,24 @@ class FileEntry(HBox):
         "Displays a file selector when Browse is pressed"
 
         try:
-            fsel = dialog.FileSelector(None, self.title, self.type)
+            # Get parent window for the file selector
+            toplevel = self.get_toplevel()
+            parent = toplevel if isinstance(toplevel, Gtk.Window) else None
+
+            fsel = dialog.FileSelector(parent, self.title, self.type)
             file = self.get_filename()
 
-            if file != None:
-                fsel.set_filename(file)
+            # Only set filename if it's not empty and is a valid path
+            if file and file != "" and file != "/":
+                try:
+                    fsel.set_filename(file)
+                except (ValueError, TypeError):
+                    # If setting filename fails, just continue without it
+                    pass
 
-            self.set_filename(fsel.run())
+            filename = fsel.run()
+            if filename:
+                self.set_filename(filename)
 
         except dialog.CancelError:
             pass
@@ -658,6 +502,7 @@ class PasswordEntry(Gtk.Entry):
     def __init__(self, password = None, cfg = None, clipboard = None):
         Gtk.Entry.__init__(self)
         self.set_visibility(False)
+        self.set_activates_default(True)
         if password:
             self.set_text(password)
 
@@ -668,13 +513,13 @@ class PasswordEntry(Gtk.Entry):
         self.connect("changed", self.__cb_check_password)
         self.connect("populate-popup", self.__cb_popup)
 
-        if cfg != None:
+        if cfg is not None:
             self.config.bind('view-passwords', self, "visibility", Gio.SettingsBindFlags.DEFAULT)
 
     def __cb_check_password(self, widget, data = None):
         "Callback for changed, checks the password"
 
-        if self.autocheck == False:
+        if not self.autocheck:
             return
 
         password = self.get_text()
@@ -695,8 +540,8 @@ class PasswordEntry(Gtk.Entry):
     def __cb_popup(self, widget, menu):
         "Populates the popup menu"
 
-        if self.clipboard != None:
-            menuitem = ImageMenuItem(Gtk.STOCK_COPY, _('Copy password'))
+        if self.clipboard is not None:
+            menuitem = ImageMenuItem("edit-copy", _('Copy password'))
             menuitem.connect("activate", lambda w: self.clipboard.set([self.get_text()], True))
 
             menu.insert(menuitem, 2)
@@ -710,17 +555,19 @@ class PasswordEntry(Gtk.Entry):
         self.set_icon_tooltip_text(Gtk.EntryIconPosition.SECONDARY, reason)
 
 
-class PasswordEntryGenerate(HBox):
+class PasswordEntryGenerate(Gtk.Box):
     "A password entry with a generator button"
 
     def __init__(self, password = None, cfg = None, clipboard = None):
-        HBox.__init__(self)
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
+        self.set_spacing(6)
         self.config = cfg
 
         self.pwentry = PasswordEntry(password, cfg, clipboard)
         self.pack_start(self.pwentry, True, True, 0)
 
-        self.button = Button(_('Generate'), lambda w: self.generate())
+        self.button = Gtk.Button(label=_('Generate'))
+        self.button.connect("clicked", lambda w: self.generate())
         self.pack_start(self.button, False, False, 0)
 
         self.entry = self.pwentry
@@ -742,37 +589,8 @@ class PasswordEntryGenerate(HBox):
         self.pwentry.set_text(text)
 
 
-class SpinEntry(Gtk.SpinButton):
-    "An entry for numbers"
-
-    def __init__(self, adjustment = None, climb_rate = 0.0, digits = 0):
-        Gtk.SpinButton.__init__(self)
-        self.configure(adjustment, climb_rate, digits)
-
-        self.set_increments(1, 5)
-        self.set_range(0, 100000)
-        self.set_numeric(True)
-
-
 # BUTTONS #
 
-class Button(Gtk.Button):
-    "A normal button"
-
-    def __init__(self, label, callback = None):
-        Gtk.Button.__init__(self, label=label)
-
-        if callback is not None:
-            self.connect("clicked", callback)
-
-
-class CheckButton(Gtk.CheckButton):
-    "A checkbutton"
-
-    def __init__(self, label = None):
-        Gtk.CheckButton.__init__(self, label=label)
-
-
 class DropDown(Gtk.ComboBox):
     "A dropdown button"
 
@@ -782,7 +600,7 @@ class DropDown(Gtk.ComboBox):
         self.model = Gtk.ListStore(GObject.TYPE_STRING, GObject.TYPE_STRING, GObject.TYPE_PYOBJECT)
         self.set_model(self.model)
 
-        if icons == True:
+        if icons:
             cr = Gtk.CellRendererPixbuf()
             cr.set_fixed_size(Gtk.icon_size_lookup(ICON_SIZE_DROPDOWN)[1] + 5, -1)
             self.pack_start(cr, False)
@@ -805,13 +623,6 @@ class DropDown(Gtk.ComboBox):
 
         self.model.append((text, stock, data))
 
-    def delete_item(self, index):
-        "Removes an item from the dropdown"
-
-        if self.model.iter_n_children(None) > index:
-            iter = self.model.iter_nth_child(None, index)
-            self.model.remove(iter)
-
     def get_active_item(self):
         "Returns a tuple with data for the current item"
 
@@ -855,36 +666,10 @@ class EntryDropDown(DropDown):
     def set_active_type(self, entrytype):
         "Set the active type"
 
-        for i in range(self.model.iter_n_children(None)):
-            iter = self.model.iter_nth_child(None, i)
-
-            if self.model.get_value(iter, 2) == entrytype:
+        for i in range(self.get_num_items()):
+            if self.get_item(i)[2] == entrytype:
                 self.set_active(i)
-
-
-class FileButton(Gtk.FileChooserButton):
-    "A file chooser button"
-
-    def __init__(self, title = None, file = None, type = Gtk.FileChooserAction.OPEN):
-        Gtk.FileChooserButton.__init__(self, title)
-        self.set_action(type)
-        self.set_local_only(False)
-
-        if file != None:
-            self.set_filename(file)
-
-    def get_filename(self):
-        "Gets the filename"
-
-        return io.file_normpath(self.get_uri())
-
-    def set_filename(self, filename):
-        "Sets the filename"
-
-        filename = io.file_normpath(filename)
-
-        if filename != io.file_normpath(self.get_filename()):
-            Gtk.FileChooserButton.set_filename(self, filename)
+                break
 
 
 class LinkButton(Gtk.LinkButton):
@@ -911,26 +696,34 @@ class LinkButton(Gtk.LinkButton):
         self.label.set_justify(justify)
 
 
-class RadioButton(Gtk.RadioButton):
-    "A radio button"
-
-    def __init__(self, group, label):
-        Gtk.RadioButton.__init__(self, group, label)
-
-
 # MENUS AND MENU ITEMS #
 
-class ImageMenuItem(Gtk.ImageMenuItem):
-    "A menuitem with a stock icon"
+class ImageMenuItem(Gtk.MenuItem):
+    "A menuitem with an icon"
 
     def __init__(self, stock, text = None):
-        Gtk.ImageMenuItem.__init__(self, stock)
+        Gtk.MenuItem.__init__(self)
 
-        self.label = self.get_children()[0]
-        self.image = self.get_image()
+        # Create a horizontal box for image and label
+        box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
+        box.set_spacing(6)
 
+        # Create and add image
+        self.image = Gtk.Image()
+        self.image.set_from_icon_name(stock, Gtk.IconSize.MENU)
+        box.pack_start(self.image, False, False, 0)
+
+        # Create and add label
+        self.label = Gtk.Label()
         if text is not None:
-            self.set_text(text)
+            self.label.set_text(text)
+        else:
+            # Try to get text from stock icon name
+            self.label.set_text("")
+        box.pack_start(self.label, True, True, 0)
+
+        # Add box to menuitem
+        self.add(box)
 
     def set_stock(self, stock):
         "Set the stock item to use as icon"
@@ -979,16 +772,16 @@ class TreeView(Gtk.TreeView):
             self.unselect_all()
 
         # handle doubleclick
-        if data.button == 1 and data.type == Gdk.EventType._2BUTTON_PRESS and path != None:
+        if data.button == 1 and data.type == Gdk.EventType._2BUTTON_PRESS and path is not None:
             iter = self.model.get_iter(path[0])
             self.toggle_expanded(iter)
 
-            if iter != None:
+            if iter is not None:
                 self.emit("doubleclick", iter)
 
         # display popup on right-click
         elif data.button == 3:
-            if path != None and self.selection.iter_is_selected(self.model.get_iter(path[0])) == False:
+            if path is not None and not self.selection.iter_is_selected(self.model.get_iter(path[0])):
                 self.set_cursor(path[0], path[1], False)
 
             self.emit("popup", data)
@@ -996,7 +789,7 @@ class TreeView(Gtk.TreeView):
             return True
 
         # handle drag-and-drop of multiple rows
-        elif self.__cbid_drag_motion is None and data.button in (1, 2) and data.type == Gdk.EventType.BUTTON_PRESS and path != None and self.selection.iter_is_selected(self.model.get_iter(path[0])) == True and len(self.get_selected()) > 1:
+        elif self.__cbid_drag_motion is None and data.button in (1, 2) and data.type == Gdk.EventType.BUTTON_PRESS and path is not None and self.selection.iter_is_selected(self.model.get_iter(path[0])) and len(self.get_selected()) > 1:
             self.__cbid_drag_motion = self.connect("motion-notify-event", self.__cb_drag_motion, data.copy())
             self.__cbid_drag_end = self.connect("button-release-event", self.__cb_button_release, data.copy())
 
@@ -1011,7 +804,7 @@ class TreeView(Gtk.TreeView):
     def __cb_drag_motion(self, widget, data, userdata = None):
         "Monitors drag motion"
 
-        if self.drag_check_threshold(int(userdata.x), int(userdata.y), int(data.x), int(data.y)) == True:
+        if self.drag_check_threshold(int(userdata.x), int(userdata.y), int(data.x), int(data.y)):
             self.__drag_check_end()
             uritarget = Gtk.TargetEntry.new("revelation/treerow", Gtk.TargetFlags.SAME_APP | Gtk.TargetFlags.SAME_WIDGET, 0)
             self.drag_begin_with_coordinates(Gtk.TargetList([uritarget]), Gdk.DragAction.MOVE, userdata.button.button, userdata, userdata.x, userdata.y)
@@ -1060,7 +853,7 @@ class TreeView(Gtk.TreeView):
 
         iter = self.model.get_iter(self.get_cursor()[0])
 
-        if iter is None or self.selection.iter_is_selected(iter) == False:
+        if iter is None or not self.selection.iter_is_selected(iter):
             return None
 
         return iter
@@ -1163,7 +956,7 @@ class EntryTree(TreeView):
         for i in range(self.model.iter_n_children(iter)):
             child = self.model.iter_nth_child(iter, i)
 
-            if self.row_expanded(self.model.get_path(child)) == False:
+            if not self.row_expanded(self.model.get_path(child)):
                 self.model.folder_expanded(child, False)
 
         self.model.folder_expanded(iter, True)
@@ -1199,86 +992,6 @@ class Statusbar(Gtk.Statusbar):
         self.push(self.contextid, text or "")
 
 
-# ACTION HANDLING #
-
-class Action(Gtk.Action):
-    "UI Manager Action"
-
-    def __init__(self, name, label = None, tooltip = None, stock = "", important = False):
-        Gtk.Action.__init__(self, name, label, tooltip, stock)
-
-        if important == True:
-            self.set_property("is-important", True)
-
-
-class ActionGroup(Gtk.ActionGroup):
-    "UI Manager Actiongroup"
-
-    def add_action(self, action, accel = None):
-        "Adds an action to the actiongroup"
-
-        if accel is None:
-            Gtk.ActionGroup.add_action(self, action)
-
-        else:
-            self.add_action_with_accel(action, accel)
-
-
-class ToggleAction(Gtk.ToggleAction):
-    "A toggle action item"
-
-    def __init__(self, name, label, tooltip = None, stock = None):
-        Gtk.ToggleAction.__init__(self, name, label, tooltip, stock)
-
-
-class UIManager(Gtk.UIManager):
-    "UI item manager"
-
-    def __init__(self):
-        Gtk.UIManager.__init__(self)
-
-        self.connect("connect-proxy", self.__cb_connect_proxy)
-
-    def __cb_connect_proxy(self, uimanager, action, widget):
-        "Callback for connecting proxies to an action"
-
-        if type(widget) in (Gtk.MenuItem, Gtk.ImageMenuItem, Gtk.CheckMenuItem):
-            widget.tooltip = action.get_property("tooltip")
-
-        else:
-            widget.set_property("label", widget.get_property("label").replace("...", ""))
-
-    def add_ui_from_file(self, file):
-        "Loads ui from a file"
-
-        try:
-            Gtk.UIManager.add_ui_from_file(self, file)
-
-        except GObject.GError:
-            raise IOError
-
-    def append_action_group(self, actiongroup):
-        "Appends an action group"
-
-        Gtk.UIManager.insert_action_group(self, actiongroup, len(self.get_action_groups()))
-
-    def get_action(self, name):
-        "Looks up an action in the managers actiongroups"
-
-        for actiongroup in self.get_action_groups():
-            action = actiongroup.get_action(name)
-
-            if action is not None:
-                return action
-
-    def get_action_group(self, name):
-        "Returns the named action group"
-
-        for actiongroup in self.get_action_groups():
-            if actiongroup.get_name() == name:
-                return actiongroup
-
-
 # APPLICATION COMPONENTS #
 
 class AppWindow(Gtk.ApplicationWindow):
@@ -1301,14 +1014,14 @@ class App(Gtk.Application):
         "Connects a menus items to the statusbar"
 
         for item in menu.get_children():
-            if isinstance(item, Gtk.MenuItem) == True:
+            if isinstance(item, Gtk.MenuItem):
                 item.connect("select", self.cb_menudesc, True)
                 item.connect("deselect", self.cb_menudesc, False)
 
     def cb_menudesc(self, item, show):
         "Displays menu descriptions in the statusbar"
 
-        if show == True:
+        if show:
             self.statusbar.set_status(item.get_label())
 
         else:
@@ -1391,13 +1104,13 @@ class App(Gtk.Application):
         self.main_vbox.pack_start(widget, True, True, 0)
 
 
-class EntryView(VBox):
+class EntryView(Gtk.Box):
     "A component for displaying an entry"
 
     def __init__(self, cfg = None, clipboard = None):
-        VBox.__init__(self)
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL)
         self.set_spacing(12)
-        self.set_border_width(12)
+        apply_css_padding(self, 12)
 
         self.config     = cfg
         self.clipboard  = clipboard
@@ -1421,7 +1134,8 @@ class EntryView(VBox):
             return
 
         # set up metadata display
-        metabox = VBox()
+        metabox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+        metabox.set_spacing(6)
         self.pack_start(metabox)
 
         label = ImageLabel(
@@ -1470,35 +1184,42 @@ class EntryView(VBox):
 
         widget.set_halign(Gtk.Align.CENTER)
         widget.set_valign(Gtk.Align.CENTER)
-        VBox.pack_start(self, widget, False, False, 0)
+        Gtk.Box.pack_start(self, widget, False, False, 0)
 
 
-class Searchbar(Toolbar):
+class Searchbar(Gtk.Toolbar):
     "A toolbar for easy searching"
 
     def __init__(self):
-        Toolbar.__init__(self)
+        Gtk.Toolbar.__init__(self)
 
-        self.entry      = Gtk.SearchEntry()
-        self.entry.set_tooltip_text(_('Text to search for'))
-        self.dropdown       = EntryDropDown()
-        self.dropdown.insert_item(0, _('Any type'), "help-about")
+        # Load UI from file
+        builder = Gtk.Builder()
+        builder.add_from_resource('/info/olasagasti/revelation/ui/searchbar.ui')
 
-        box = Gtk.Box.new(Gtk.Orientation.HORIZONTAL, 0)
+        # Get the box from UI file
+        box = builder.get_object('searchbar_box')
         Gtk.StyleContext.add_class(box.get_style_context(), "linked")
-        self.button_prev = Gtk.Button.new_from_icon_name(STOCK_PREVIOUS,
-                                                         Gtk.IconSize.BUTTON)
-        self.button_prev.set_tooltip_text(_('Find the previous match'))
-        self.button_next = Gtk.Button.new_from_icon_name(STOCK_NEXT,
-                                                         Gtk.IconSize.BUTTON)
-        self.button_next.set_tooltip_text(_('Find the next match'))
 
-        box.add(self.entry)
-        box.add(self.button_prev)
-        box.add(self.button_next)
-        box.add(self.dropdown)
+        # Get widgets from UI file
+        self.entry = builder.get_object('search_entry')
+        self.button_prev = builder.get_object('button_prev')
+        self.button_next = builder.get_object('button_next')
 
-        self.append_widget(box)
+        # Replace dropdown placeholder with EntryDropDown
+        dropdown_placeholder = builder.get_object('dropdown_placeholder')
+        self.dropdown = EntryDropDown()
+        self.dropdown.insert_item(0, _('Any type'), "help-about")
+        # Replace the placeholder in the UI
+        dropdown_parent = dropdown_placeholder.get_parent()
+        dropdown_parent.remove(dropdown_placeholder)
+        dropdown_parent.pack_start(self.dropdown, False, False, 0)
+        dropdown_parent.show_all()
+
+        # Add the search box to the toolbar
+        toolitem = Gtk.ToolItem()
+        toolitem.add(box)
+        self.insert(toolitem, -1)
 
         self.connect("show", self.__cb_show)
 
