@@ -100,7 +100,7 @@ class Revelation(ui.App):
         if len(sys.argv) > 1:
             file = sys.argv[1]
 
-        elif self.config.get_boolean("file-autoload") == True:
+        elif self.config.get_boolean("file-autoload"):
             file = self.config.get_string("file-autoload-file")
 
         else:
@@ -401,7 +401,7 @@ class Revelation(ui.App):
         self.__cb_config_toolbar_style(self.config, self.config.get_string("view-toolbar-style"))
 
         # give focus to searchbar entry if shown
-        if self.searchbar.get_property("visible") == True:
+        if self.searchbar.get_property("visible"):
             self.searchbar.entry.grab_focus()
 
     def __init_ui(self):
@@ -414,7 +414,7 @@ class Revelation(ui.App):
 
         # set window icons
         pixbufs = [self.items.load_icon("info.olasagasti.revelation", size, 0) for size in (128, 48, 32, 24, 16)]
-        pixbufs = [pixbuf for pixbuf in pixbufs if pixbuf != None]
+        pixbufs = [pixbuf for pixbuf in pixbufs if pixbuf is not None]
 
         if len(pixbufs) > 0:
             Gtk.Window.set_default_icon_list(pixbufs)
@@ -422,60 +422,35 @@ class Revelation(ui.App):
         # set up toolbar and menus
         self.set_menubar(self.menubar)
 
-        toolbar = Gtk.Toolbar.new()
-        toolbar.set_style(Gtk.ToolbarStyle.BOTH_HORIZ)
+        # Load toolbar from UI file
+        toolbarbuilder = Gtk.Builder()
+        toolbarbuilder.add_from_resource('/info/olasagasti/revelation/ui/toolbar.ui')
+        self.toolbar = toolbarbuilder.get_object('toolbar')
 
-        open_item = Gtk.ToolButton.new(Gtk.Image.new_from_icon_name('document-open', Gtk.IconSize.LARGE_TOOLBAR), _('_Open'))
+        # Connect toolbar button signals
+        open_item = toolbarbuilder.get_object('open_item')
         open_item.connect('clicked', lambda k: self.window.get_action_group("file").lookup_action("file-open").activate())
-        open_item.set_tooltip_text(_('Open a file'))
-        open_item.set_use_underline(True)
-        toolbar.insert(open_item, -1)
 
-        save_item = Gtk.ToolButton.new(Gtk.Image.new_from_icon_name('document-save', Gtk.IconSize.LARGE_TOOLBAR), _('_Save'))
+        save_item = toolbarbuilder.get_object('save_item')
         save_item.connect('clicked', lambda k: self.window.get_action_group("file").lookup_action("file-save").activate())
-        save_item.set_tooltip_text(_('Save data to a file'))
-        save_item.set_property('is-important', True)
-        save_item.set_use_underline(True)
-        toolbar.insert(save_item, -1)
 
-        toolbar.insert(Gtk.SeparatorToolItem.new(), -1)
-
-        addentry_item = Gtk.ToolButton.new(Gtk.Image.new_from_icon_name('list-add', Gtk.IconSize.LARGE_TOOLBAR), _('Add Entry'))
+        addentry_item = toolbarbuilder.get_object('addentry_item')
         addentry_item.connect('clicked', lambda k: self.window.get_action_group("entry-optional").lookup_action("entry-add").activate())
-        addentry_item.set_tooltip_text(_('Create a new entry'))
-        addentry_item.set_property('is-important', True)
-        addentry_item.set_use_underline(True)
-        toolbar.insert(addentry_item, -1)
 
-        addfolder_item = Gtk.ToolButton.new(Gtk.Image.new_from_icon_name('folder-new', Gtk.IconSize.LARGE_TOOLBAR), _('Add folder'))
+        addfolder_item = toolbarbuilder.get_object('addfolder_item')
         addfolder_item.connect('clicked', lambda k: self.window.get_action_group("entry-optional").lookup_action("entry-folder").activate())
-        addfolder_item.set_tooltip_text(_('Create a new folder'))
-        toolbar.insert(addfolder_item, -1)
 
-        toolbar.insert(Gtk.SeparatorToolItem.new(), -1)
-
-        gotoentry_item = Gtk.ToolButton.new(Gtk.Image.new_from_icon_name('go-jump', Gtk.IconSize.LARGE_TOOLBAR), _('_Go to'))
+        gotoentry_item = toolbarbuilder.get_object('gotoentry_item')
         gotoentry_item.connect('clicked', lambda k: self.window.get_action_group("dynamic").lookup_action("entry-goto").activate())
-        gotoentry_item.set_tooltip_text(_('Go to the selected entries'))
-        gotoentry_item.set_property('is-important', True)
-        gotoentry_item.set_use_underline(True)
-        toolbar.insert(gotoentry_item, -1)
 
-        editentry_item = Gtk.ToolButton.new(Gtk.Image.new_from_icon_name('document-edit', Gtk.IconSize.LARGE_TOOLBAR), _('_Edit'))
+        editentry_item = toolbarbuilder.get_object('editentry_item')
         editentry_item.connect('clicked', lambda k: self.window.get_action_group("entry-single").lookup_action("entry-edit").activate())
-        editentry_item.set_tooltip_text(_('Edit the selected entry'))
-        editentry_item.set_use_underline(True)
-        toolbar.insert(editentry_item, -1)
 
-        removeentry_item = Gtk.ToolButton.new(Gtk.Image.new_from_icon_name('edit-delete', Gtk.IconSize.LARGE_TOOLBAR), _('Re_move'))
+        removeentry_item = toolbarbuilder.get_object('removeentry_item')
         removeentry_item.connect('clicked', lambda k: self.window.get_action_group("entry-multiple").lookup_action("entry-remove").activate())
-        removeentry_item.set_tooltip_text(_('Remove the selected entries'))
-        removeentry_item.set_use_underline(True)
-        toolbar.insert(removeentry_item, -1)
 
-        self.toolbar = toolbar
         self.toolbar.connect("popup-context-menu", lambda w, x, y, b: True)
-        self.add_toolbar(toolbar, "toolbar", 1)
+        self.add_toolbar(self.toolbar, "toolbar", 1)
 
         self.statusbar = ui.Statusbar()
         self.main_vbox.pack_end(self.statusbar, False, True, 0)
@@ -485,7 +460,9 @@ class Revelation(ui.App):
 
         # set up main application widgets
         self.tree = ui.EntryTree(self.entrystore)
-        self.scrolledwindow = ui.ScrolledWindow(self.tree)
+        self.scrolledwindow = Gtk.ScrolledWindow()
+        self.scrolledwindow.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+        self.scrolledwindow.add(self.tree)
 
         self.entryview = ui.EntryView(self.config, self.clipboard)
         self.entryview.set_halign(Gtk.Align.CENTER)
@@ -495,7 +472,7 @@ class Revelation(ui.App):
         self.hpaned = Gtk.Paned.new(Gtk.Orientation.HORIZONTAL)
         self.hpaned.pack1(self.scrolledwindow, True, True)
         self.hpaned.pack2(self.entryview, True, True)
-        self.hpaned.set_border_width(6)
+        ui.apply_css_padding(self.hpaned, 6)
         self.set_contents(self.hpaned)
 
         # set up drag-and-drop
@@ -695,7 +672,7 @@ class Revelation(ui.App):
         traceback = util.trace_exception(type, value, trace)
         sys.stderr.write(traceback)
 
-        if dialog.Exception(self.window, traceback).run() == True:
+        if dialog.Exception(self.window, traceback).run():
             Gtk.main()
 
         else:
@@ -705,7 +682,7 @@ class Revelation(ui.App):
         "Callback for changed file"
 
         try:
-            if dialog.FileChanged(self.window, file).run() == True:
+            if dialog.FileChanged(self.window, file).run():
                 self.file_open(self.datafile.get_file(), self.datafile.get_password())
 
         except dialog.CancelError:
@@ -714,17 +691,17 @@ class Revelation(ui.App):
     def __cb_file_autolock(self, widget, data = None):
         "Callback for locking the file"
 
-        if self.config.get_boolean("file-autolock") == True:
+        if self.config.get_boolean("file-autolock"):
             self.file_lock()
 
     def __cb_screensaver_lock(self, connection, unique_name, object_path, interface, signal, state):
-        if state[0] is True and self.config.get_boolean("file-autolock") == True:
+        if state[0] and self.config.get_boolean("file-autolock"):
             self.file_lock()
 
     def __cb_quit(self, widget, data = None):
         "Callback for quit"
 
-        if self.quit() == False:
+        if not self.quit():
             return True
 
         else:
@@ -733,7 +710,7 @@ class Revelation(ui.App):
     def __cb_close(self, widget, data = None):
         "Callback for Close"
 
-        if self.file_close() == False:
+        if not self.file_close():
             return True
 
         else:
@@ -787,7 +764,7 @@ class Revelation(ui.App):
         for sourceiter in sourceiters:
             sourcepath = self.entrystore.get_path(sourceiter)
 
-            if self.entrystore.is_ancestor(sourceiter, destiter) == True or sourcepath == destpath:
+            if self.entrystore.is_ancestor(sourceiter, destiter) or sourcepath == destpath:
                 context.finish(False, False, time)
                 return
 
@@ -1015,7 +992,7 @@ class Revelation(ui.App):
         match = self.entrysearch.find(string, entrytype, self.tree.get_active(), direction)
         context = self.searchbar.entry.get_style_context()
 
-        if match != None:
+        if match is not None:
             self.tree.select(match)
             self.statusbar.set_status(_('Match found for “%s”') % string)
             context.remove_class(Gtk.STYLE_CLASS_ERROR)
@@ -1031,7 +1008,7 @@ class Revelation(ui.App):
             if self.datafile.get_file() is None or self.datafile.get_password() is None:
                 return
 
-            if self.config.get_boolean("file-autosave") == False:
+            if not self.config.get_boolean("file-autosave"):
                 return
 
             self.datafile.save(self.entrystore, self.datafile.get_file(), self.datafile.get_password())
@@ -1055,8 +1032,8 @@ class Revelation(ui.App):
                 # with version two. If we aren't chances are high, that we are
                 # dealing with version one. In this case we use the version one
                 # handler and save the file as version two if it is changed, to
-                # allow seemless upgrades.
-                if datafile.get_handler().detect(io.file_read(file)) != True:
+                # allow seamless upgrades.
+                if not datafile.get_handler().detect(io.file_read(file)):
                     # Store the datahandler to be reset later on
                     old_handler = datafile.get_handler()
                     # Load the revelation fileversion one handler
@@ -1092,8 +1069,8 @@ class Revelation(ui.App):
             dialog.Error(self.window, _('Unable to open file'), _('The file \'%s\' could not be opened. Make sure that the file exists, and that you have permissions to open it.') % file).run()
 
         # If we switched the datahandlers before we need to switch back to the
-        # version2 handler here, to ensure a seemless version upgrade on save
-        if old_handler != None:
+        # version2 handler here, to ensure a seamless version upgrade on save
+        if old_handler is not None:
             datafile.set_handler(old_handler.__class__)
 
         return result
@@ -1119,7 +1096,7 @@ class Revelation(ui.App):
     def about(self):
         "Displays the about dialog"
 
-        dialog.run_unique(dialog.About, self)
+        dialog.run_unique_dialog(dialog.About, self)
 
     def clip_chain(self, e):
         "Copies all passwords from an entry as a chain"
@@ -1129,7 +1106,7 @@ class Revelation(ui.App):
 
         secrets = [field.value for field in e.fields if field.datatype == entry.DATATYPE_PASSWORD and field.value != ""]
 
-        if self.config.get_boolean("clipboard-chain-username") == True and len(secrets) > 0 and e.has_field(entry.UsernameField) and e[entry.UsernameField] != "":
+        if self.config.get_boolean("clipboard-chain-username") and len(secrets) > 0 and e.has_field(entry.UsernameField) and e[entry.UsernameField] != "":
             secrets.insert(0, e[entry.UsernameField])
 
         if len(secrets) == 0:
@@ -1301,7 +1278,7 @@ class Revelation(ui.App):
                     if field.datatype == entry.DATATYPE_PASSWORD and field.value != "":
                         chain.append(field.value)
 
-                if self.config.get_boolean("clipboard-chain-username") == True and len(chain) > 0 and e.has_field(entry.UsernameField) == True and e[entry.UsernameField] != "" and "%" + entry.UsernameField.symbol not in command:
+                if self.config.get_boolean("clipboard-chain-username") and len(chain) > 0 and e.has_field(entry.UsernameField) and e[entry.UsernameField] != "" and "%" + entry.UsernameField.symbol not in command:
                     chain.insert(0, e[entry.UsernameField])
 
                 self.clipboard.set(chain, True)
@@ -1401,8 +1378,8 @@ class Revelation(ui.App):
         "Closes the current file"
 
         try:
-            if self.entrystore.changed == True and dialog.FileChangesClose(self.window).run() == True:
-                if self.file_save(self.datafile.get_file(), self.datafile.get_password()) == False:
+            if self.entrystore.changed and dialog.FileChangesClose(self.window).run():
+                if not self.file_save(self.datafile.get_file(), self.datafile.get_password()):
                     raise dialog.CancelError
 
             self.clipboard.clear()
@@ -1425,7 +1402,7 @@ class Revelation(ui.App):
             file, handler = dialog.ExportFileSelector(self.window).run()
             datafile = io.DataFile(handler)
 
-            if datafile.get_handler().encryption == True:
+            if datafile.get_handler().encryption:
                 password = dialog.PasswordSave(self.window, file).run()
 
             else:
@@ -1506,7 +1483,7 @@ class Revelation(ui.App):
         try:
             d = dialog.PasswordLock(self.window, password)
 
-            if self.entrystore.changed == True:
+            if self.entrystore.changed:
                 l = ui.ImageLabel(_('Quit disabled due to unsaved changes'), "dialog-warning")
                 d.contents.pack_start(l, True, True, 0)
                 d.get_widget_for_response(Gtk.ResponseType.CANCEL).set_sensitive(False)
@@ -1534,8 +1511,8 @@ class Revelation(ui.App):
         "Opens a new file"
 
         try:
-            if self.entrystore.changed == True and dialog.FileChangesNew(self.window).run() == True:
-                if self.file_save(self.datafile.get_file(), self.datafile.get_password()) == False:
+            if self.entrystore.changed and dialog.FileChangesNew(self.window).run():
+                if not self.file_save(self.datafile.get_file(), self.datafile.get_password()):
                     raise dialog.CancelError
 
             self.entrystore.clear()
@@ -1550,8 +1527,8 @@ class Revelation(ui.App):
         "Opens a data file"
 
         try:
-            if self.entrystore.changed == True and dialog.FileChangesOpen(self.window).run() == True:
-                if self.file_save(self.datafile.get_file(), self.datafile.get_password()) == False:
+            if self.entrystore.changed and dialog.FileChangesOpen(self.window).run():
+                if not self.file_save(self.datafile.get_file(), self.datafile.get_password()):
                     raise dialog.CancelError
 
             if file is None:
@@ -1602,24 +1579,24 @@ class Revelation(ui.App):
     def prefs(self):
         "Displays the application preferences"
 
-        dialog.run_unique(Preferences, self.window, self.config)
+        dialog.run_unique_dialog(Preferences, self.window, self.config)
 
     def pwcheck(self):
         "Displays the password checking dialog"
 
-        dialog.run_unique(dialog.PasswordChecker, self.window, self.config, self.clipboard)
+        dialog.run_unique_dialog(dialog.PasswordChecker, self.window, self.config, self.clipboard)
 
     def pwgen(self):
         "Displays the password generator dialog"
 
-        dialog.run_unique(dialog.PasswordGenerator, self.window, self.config, self.clipboard)
+        dialog.run_unique_dialog(dialog.PasswordGenerator, self.window, self.config, self.clipboard)
 
     def quit(self):
         "Quits the application"
 
         try:
-            if self.entrystore.changed == True and dialog.FileChangesQuit(self.window).run() == True:
-                if self.file_save(self.datafile.get_file(), self.datafile.get_password()) == False:
+            if self.entrystore.changed and dialog.FileChangesQuit(self.window).run():
+                if not self.file_save(self.datafile.get_file(), self.datafile.get_password()):
                     raise dialog.CancelError
 
             self.clipboard.clear()
@@ -1669,24 +1646,39 @@ class Preferences(dialog.Utility):
 
     def __init__(self, parent, cfg=None):
         dialog.Utility.__init__(self, parent, _('Preferences'))
-        self.add_button(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
+        self.add_button(_("_Close"), Gtk.ResponseType.CLOSE)
         self.set_default_response(Gtk.ResponseType.CLOSE)
         self.config = cfg
         self.set_modal(False)
 
-        self.notebook = ui.Notebook()
-        self.vbox.pack_start(self.notebook, True, True, 0)
+        # Load notebook and pages from UI file
+        builder = Gtk.Builder()
+        builder.add_from_resource('/info/olasagasti/revelation/ui/preferences.ui')
+        self.notebook = builder.get_object('preferences_notebook')
+        self.get_content_area().pack_start(self.notebook, True, True, 0)
 
-        self.page_general = self.notebook.create_page(_('General'))
+        # Get pages and tab labels from UI file
+        self.page_general = builder.get_object('page_general')
+        tab_general = builder.get_object('tab_general')
+        ui.apply_css_padding(self.page_general, 12)
+        self.page_general.sizegroup = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
+        self.notebook.append_page(self.page_general, tab_general)
         self.__init_section_files(self.page_general)
         self.__init_section_password(self.page_general)
 
-        self.page_interface = self.notebook.create_page(_('Interface'))
+        self.page_interface = builder.get_object('page_interface')
+        tab_interface = builder.get_object('tab_interface')
+        ui.apply_css_padding(self.page_interface, 12)
+        self.page_interface.sizegroup = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
+        self.notebook.append_page(self.page_interface, tab_interface)
         self.__init_section_doubleclick(self.page_interface)
         self.__init_section_toolbar(self.page_interface)
 
-        self.page_gotocmd = self.notebook.create_page(_('Goto Commands'))
-        self.notebook.get_tab_label(self.page_gotocmd).set_hexpand(True)
+        self.page_gotocmd = builder.get_object('page_gotocmd')
+        tab_gotocmd = builder.get_object('tab_gotocmd')
+        ui.apply_css_padding(self.page_gotocmd, 12)
+        self.page_gotocmd.sizegroup = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
+        self.notebook.append_page(self.page_gotocmd, tab_gotocmd)
         self.__init_section_gotocmd(self.page_gotocmd)
 
         self.connect("response", lambda w, d: self.destroy())
@@ -1694,29 +1686,36 @@ class Preferences(dialog.Utility):
     def __init_section_doubleclick(self, page):
         "Sets up the doubleclick section"
 
-        self.section_doubleclick = page.add_section(_('Doubleclick Action'))
+        # Load UI from file
+        builder = Gtk.Builder()
+        builder.add_from_resource('/info/olasagasti/revelation/ui/preferences-doubleclick.ui')
 
-        # radio-button for go to
-        self.radio_doubleclick_goto = Gtk.RadioButton.new_with_label_from_widget(None, _('Go to account, if possible'))
+        # Get the section from UI file
+        doubleclick_section = builder.get_object('doubleclick_section')
+
+        # Set section title with markup
+        doubleclick_title = builder.get_object('doubleclick_title')
+        doubleclick_title.set_markup(f"<span weight='bold'>{util.escape_markup(_('Doubleclick Action'))}</span>")
+
+        # Add section to page
+        page.pack_start(doubleclick_section, False, False, 0)
+        self.section_doubleclick = doubleclick_section
+
+        # Get radio buttons from UI file
+        self.radio_doubleclick_goto = builder.get_object('radio_doubleclick_goto')
+        self.radio_doubleclick_edit = builder.get_object('radio_doubleclick_edit')
+        self.radio_doubleclick_copy = builder.get_object('radio_doubleclick_copy')
+
+        # Set up radio button group
+        self.radio_doubleclick_edit.join_group(self.radio_doubleclick_goto)
+        self.radio_doubleclick_copy.join_group(self.radio_doubleclick_goto)
+
+        # Connect signals
         self.radio_doubleclick_goto.connect("toggled", lambda w: w.get_active() and self.config.set_string("behavior-doubleclick", "goto"))
-
-        self.radio_doubleclick_goto.set_tooltip_text(_('Go to the account (open in external application) on doubleclick, if required data is filled in'))
-        self.section_doubleclick.append_widget(None, self.radio_doubleclick_goto)
-
-        # radio-button for edit
-        self.radio_doubleclick_edit = Gtk.RadioButton.new_with_label_from_widget(self.radio_doubleclick_goto, label=_('Edit account'))
         self.radio_doubleclick_edit.connect("toggled", lambda w: w.get_active() and self.config.set_string("behavior-doubleclick", "edit"))
-
-        self.radio_doubleclick_edit.set_tooltip_text(_('Edit the account on doubleclick'))
-        self.section_doubleclick.append_widget(None, self.radio_doubleclick_edit)
-
-        # radio-button for copy
-        self.radio_doubleclick_copy = Gtk.RadioButton.new_with_label_from_widget(self.radio_doubleclick_goto, label=_('Copy password to clipboard'))
         self.radio_doubleclick_copy.connect("toggled", lambda w: w.get_active() and self.config.set_string("behavior-doubleclick", "copy"))
 
-        self.radio_doubleclick_copy.set_tooltip_text(_('Copy the account password to clipboard on doubleclick'))
-        self.section_doubleclick.append_widget(None, self.radio_doubleclick_copy)
-
+        # Set active radio button based on config
         {"goto": self.radio_doubleclick_goto,
          "edit": self.radio_doubleclick_edit,
          "copy": self.radio_doubleclick_copy}[self.config.get_string("behavior-doubleclick")].set_active(True)
@@ -1724,22 +1723,44 @@ class Preferences(dialog.Utility):
     def __init_section_files(self, page):
         "Sets up the files section"
 
-        self.section_files = page.add_section(_('Files'))
+        # Load UI from file
+        builder = Gtk.Builder()
+        builder.add_from_resource('/info/olasagasti/revelation/ui/preferences-files.ui')
 
-        # checkbutton and file button for autoloading a file
-        self.check_autoload = Gtk.CheckButton(label=_('Open file on startup:'))
+        # Get the section from UI file
+        files_section = builder.get_object('files_section')
+
+        # Set section title with markup
+        files_title = builder.get_object('files_title')
+        files_title.set_markup(f"<span weight='bold'>{util.escape_markup(_('Files'))}</span>")
+
+        # Add section to page
+        page.pack_start(files_section, False, False, 0)
+        self.section_files = files_section
+
+        # Get widgets from UI file
+        self.check_autoload = builder.get_object('check_autoload')
+        self.button_autoload_file = builder.get_object('button_autoload_file')
+        self.check_autosave = builder.get_object('check_autosave')
+        self.check_autolock = builder.get_object('check_autolock')
+
+        # Set up GSettings bindings
         self.config.bind("file-autoload", self.check_autoload, "active", Gio.SettingsBindFlags.DEFAULT)
+        self.config.bind("file-autosave", self.check_autosave, "active", Gio.SettingsBindFlags.DEFAULT)
+        self.config.bind("file-autolock", self.check_autolock, "active", Gio.SettingsBindFlags.DEFAULT)
 
+        # Connect signals
         self.check_autoload.connect("toggled", lambda w: self.button_autoload_file.set_sensitive(w.get_active()))
-        self.check_autoload.set_tooltip_text(_('When enabled, this file will be opened when the program is started'))
+        self.check_autolock.connect("toggled", lambda w: self.spin_autolock_timeout.set_sensitive(w.get_active()))
 
-        self.button_autoload_file = Gtk.FileChooserButton(title=_('Select File to Automatically Open'))
+        # Set up file chooser button
         if self.config.get_boolean("file-autoload"):
             self.button_autoload_file.set_filename(self.config.get_string("file-autoload-file"))
         self.button_autoload_file.connect('file-set', lambda w: self.config.set_string("file-autoload-file", w.get_filename()))
         self.config.connect("changed::autoload-file", lambda w, fname: self.button_autoload_file.set_filename(w.get_string(fname)))
         self.button_autoload_file.set_sensitive(self.check_autoload.get_active())
 
+        # Add file filters
         filter = Gtk.FileFilter()
         filter.set_name(_('Revelation files'))
         filter.add_mime_type("application/x-revelation")
@@ -1750,44 +1771,17 @@ class Preferences(dialog.Utility):
         filter.add_pattern("*")
         self.button_autoload_file.add_filter(filter)
 
-        eventbox = ui.EventBox(self.button_autoload_file)
-        eventbox.set_tooltip_text(_('File to open when Revelation is started'))
-
-        hbox = ui.HBox()
-        hbox.pack_start(self.check_autoload, False, False, 0)
-        hbox.pack_start(eventbox, True, True, 0)
-        self.section_files.append_widget(None, hbox)
-
-        # check-button for autosave
-        self.check_autosave = Gtk.CheckButton(label=_('Automatically save data when changed'))
-        self.config.bind("file-autosave", self.check_autosave, "active", Gio.SettingsBindFlags.DEFAULT)
-
-        self.check_autosave.set_tooltip_text(_('Automatically save the data file when an entry is added, modified or removed'))
-        self.section_files.append_widget(None, self.check_autosave)
-
-        # autolock file
-        self.check_autolock = Gtk.CheckButton(label=_('Lock file when inactive for'))
-        self.config.bind("file-autolock", self.check_autolock, "active", Gio.SettingsBindFlags.DEFAULT)
-        self.check_autolock.connect("toggled", lambda w: self.spin_autolock_timeout.set_sensitive(w.get_active()))
-        self.check_autolock.set_tooltip_text(_('Automatically lock the data file after a period of inactivity'))
-
-        self.spin_autolock_timeout = ui.SpinEntry()
-        self.spin_autolock_timeout.set_range(1, 120)
+        # Get spin button from UI file (range and adjustment already set in XML)
+        self.spin_autolock_timeout = builder.get_object('spin_autolock_timeout')
         self.spin_autolock_timeout.set_sensitive(self.check_autolock.get_active())
         self.config.bind("file-autolock-timeout", self.spin_autolock_timeout, "value", Gio.SettingsBindFlags.DEFAULT)
-        self.spin_autolock_timeout.set_tooltip_text(_('The period of inactivity before locking the file, in minutes'))
-
-        hbox = ui.HBox()
-        hbox.set_spacing(3)
-        hbox.pack_start(self.check_autolock, False, False, 0)
-        hbox.pack_start(self.spin_autolock_timeout, False, False, 0)
-        hbox.pack_start(ui.Label(_('minutes')), True, True, 0)
-        self.section_files.append_widget(None, hbox)
 
     def __init_section_gotocmd(self, page):
         "Sets up the goto command section"
 
-        self.section_gotocmd = page.add_section(_('Goto Commands'))
+        section = ui.InputSection(_('Goto Commands'), None, page.sizegroup)
+        page.pack_start(section, False, False, 0)
+        self.section_gotocmd = section
 
         for entrytype in entry.ENTRYLIST:
             if entrytype == entry.FolderEntry:
@@ -1814,77 +1808,78 @@ class Preferences(dialog.Utility):
     def __init_section_password(self, page):
         "Sets up the password section"
 
-        self.section_password = page.add_section(_('Passwords'))
+        # Load UI from file
+        builder = Gtk.Builder()
+        builder.add_from_resource('/info/olasagasti/revelation/ui/preferences-passwords.ui')
 
-        # show passwords checkbutton
-        self.check_show_passwords = Gtk.CheckButton(label=_('Display passwords and other secrets'))
+        # Get the section from UI file
+        passwords_section = builder.get_object('passwords_section')
+
+        # Set section title with markup
+        passwords_title = builder.get_object('passwords_title')
+        passwords_title.set_markup(f"<span weight='bold'>{util.escape_markup(_('Passwords'))}</span>")
+
+        # Add section to page
+        page.pack_start(passwords_section, False, False, 0)
+        self.section_password = passwords_section
+
+        # Get widgets from UI file
+        self.check_show_passwords = builder.get_object('check_show_passwords')
+        self.check_chain_username = builder.get_object('check_chain_username')
+        self.check_punctuation_chars = builder.get_object('check_punctuation_chars')
+
+        # Set up GSettings bindings
         self.config.bind("view-passwords", self.check_show_passwords, "active", Gio.SettingsBindFlags.DEFAULT)
-
-        self.check_show_passwords.set_tooltip_text(_('Display passwords and other secrets, such as PIN codes (otherwise, hide with ******)'))
-        self.section_password.append_widget(None, self.check_show_passwords)
-
-        # chain username checkbutton
-        self.check_chain_username = Gtk.CheckButton(label=_('Also copy username when copying password'))
         self.config.bind("clipboard-chain-username", self.check_chain_username, "active", Gio.SettingsBindFlags.DEFAULT)
-
-        self.check_chain_username.set_tooltip_text(_('When the password is copied to clipboard, put the username before the password as a clipboard "chain"'))
-        self.section_password.append_widget(None, self.check_chain_username)
-
-        # use punctuation chars checkbutton
-        self.check_punctuation_chars = Gtk.CheckButton(label=_('Use punctuation characters for passwords'))
         self.config.bind("passwordgen-punctuation", self.check_punctuation_chars, "active", Gio.SettingsBindFlags.DEFAULT)
 
-        self.check_punctuation_chars.set_tooltip_text(_('When passwords are generated, use punctuation characters like %, =, { or .'))
-        self.section_password.append_widget(None, self.check_punctuation_chars)
-
-        # password length spinbutton
-        self.spin_pwlen = ui.SpinEntry()
-        self.spin_pwlen.set_range(4, 32)
+        # Get spin button from UI file (range and adjustment already set in XML)
+        self.spin_pwlen = builder.get_object('spin_pwlen')
         self.config.bind("passwordgen-length", self.spin_pwlen, "value", Gio.SettingsBindFlags.DEFAULT)
 
-        self.spin_pwlen.set_tooltip_text(_('The number of characters in generated passwords - 8 or more are recommended'))
-        self.section_password.append_widget(_('Length of generated passwords'), self.spin_pwlen)
+        # Add label to sizegroup for alignment
+        password_length_label = builder.get_object('password_length_label')
+        page.sizegroup.add_widget(password_length_label)
 
     def __init_section_toolbar(self, page):
         "Sets up the toolbar section"
 
-        self.section_toolbar = page.add_section(_('Toolbar Style'))
+        # Load UI from file
+        builder = Gtk.Builder()
+        builder.add_from_resource('/info/olasagasti/revelation/ui/preferences-toolbar.ui')
 
-        # radio-button for desktop default
-        self.radio_toolbar_desktop = Gtk.RadioButton.new_with_label_from_widget(None, _('Use desktop default'))
+        # Get the section from UI file
+        toolbar_section = builder.get_object('toolbar_section')
+
+        # Set section title with markup
+        toolbar_title = builder.get_object('toolbar_title')
+        toolbar_title.set_markup(f"<span weight='bold'>{util.escape_markup(_('Toolbar Style'))}</span>")
+
+        # Add section to page
+        page.pack_start(toolbar_section, False, False, 0)
+        self.section_toolbar = toolbar_section
+
+        # Get radio buttons from UI file
+        self.radio_toolbar_desktop = builder.get_object('radio_toolbar_desktop')
+        self.radio_toolbar_both = builder.get_object('radio_toolbar_both')
+        self.radio_toolbar_bothhoriz = builder.get_object('radio_toolbar_bothhoriz')
+        self.radio_toolbar_icons = builder.get_object('radio_toolbar_icons')
+        self.radio_toolbar_text = builder.get_object('radio_toolbar_text')
+
+        # Set up radio button group
+        self.radio_toolbar_both.join_group(self.radio_toolbar_desktop)
+        self.radio_toolbar_bothhoriz.join_group(self.radio_toolbar_desktop)
+        self.radio_toolbar_icons.join_group(self.radio_toolbar_desktop)
+        self.radio_toolbar_text.join_group(self.radio_toolbar_desktop)
+
+        # Connect signals
         self.radio_toolbar_desktop.connect("toggled", lambda w: w.get_active() and self.config.set_string("view-toolbar-style", "desktop"))
-
-        self.radio_toolbar_desktop.set_tooltip_text(_('Show toolbar items with default style'))
-        self.section_toolbar.append_widget(None, self.radio_toolbar_desktop)
-
-        # radio-button for icons and text
-        self.radio_toolbar_both = Gtk.RadioButton.new_with_label_from_widget(self.radio_toolbar_desktop, _('Show icons and text'))
         self.radio_toolbar_both.connect("toggled", lambda w: w.get_active() and self.config.set_string("view-toolbar-style", "both"))
-
-        self.radio_toolbar_both.set_tooltip_text(_('Show toolbar items with both icons and text'))
-        self.section_toolbar.append_widget(None, self.radio_toolbar_both)
-
-        # radio-button for icons and important text
-        self.radio_toolbar_bothhoriz = Gtk.RadioButton.new_with_label_from_widget(self.radio_toolbar_desktop, _('Show icons and important text'))
         self.radio_toolbar_bothhoriz.connect("toggled", lambda w: w.get_active() and self.config.set_string("view-toolbar-style", "both-horiz"))
-
-        self.radio_toolbar_bothhoriz.set_tooltip_text(_('Show toolbar items with text beside important icons'))
-        self.section_toolbar.append_widget(None, self.radio_toolbar_bothhoriz)
-
-        # radio-button for icons only
-        self.radio_toolbar_icons = Gtk.RadioButton.new_with_label_from_widget(self.radio_toolbar_desktop, _('Show icons only'))
         self.radio_toolbar_icons.connect("toggled", lambda w: w.get_active() and self.config.set_string("view-toolbar-style", "icons"))
-
-        self.radio_toolbar_icons.set_tooltip_text(_('Show toolbar items with icons only'))
-        self.section_toolbar.append_widget(None, self.radio_toolbar_icons)
-
-        # radio-button for text only
-        self.radio_toolbar_text = Gtk.RadioButton.new_with_label_from_widget(self.radio_toolbar_desktop, _('Show text only'))
         self.radio_toolbar_text.connect("toggled", lambda w: w.get_active() and self.config.set_string("view-toolbar-style", "text"))
 
-        self.radio_toolbar_text.set_tooltip_text(_('Show toolbar items with text only'))
-        self.section_toolbar.append_widget(None, self.radio_toolbar_text)
-
+        # Set active radio button based on config
         {"desktop":    self.radio_toolbar_desktop,
          "both":       self.radio_toolbar_both,
          "both-horiz": self.radio_toolbar_bothhoriz,
